@@ -129,7 +129,7 @@ pub fn optimize_circuit(circuit: CircuitRc, settings: OptimizationSettings) -> C
         circuit.compiler_print();
     }
     let circuit = timed!(
-        apply_fn_until_same(&circuit, &mut |x| compiler_simp(&deep_maybe_distribute(
+        apply_fn_until_same(&circuit, |x| compiler_simp(&deep_maybe_distribute(
             x, settings
         ))),
         10,
