@@ -40,7 +40,7 @@ pub fn deep_maybe_distribute_py(node: CircuitRc, settings: OptimizationSettings)
 }
 
 pub fn deep_maybe_distribute(node: &Circuit, settings: OptimizationSettings) -> CircuitRc {
-    deep_map_op(node, &mut |x: &Circuit| match x {
+    deep_map_op(node, |x: &Circuit| match x {
         Circuit::Einsum(ein) => maybe_distribute(ein, settings),
         _ => None,
     })
