@@ -30,7 +30,7 @@ macro_rules! circuit_node_auto_leaf_impl {
 
         fn map_children_enumerate<'a, F, E>(
             &'a self,
-            _f: &mut F,
+            _f: F,
         ) -> Result<Self, CircuitConstructionError>
         where
             CircuitConstructionError: From<E>,
