@@ -214,12 +214,12 @@ pub fn compiler_simp(circ: &Circuit) -> CircuitRc {
 
 #[pyfunction]
 pub fn compiler_simp_until_same(circ: CircuitRc) -> CircuitRc {
-    apply_fn_until_same(&circ, &mut |x: &CircuitRc| compiler_simp(x))
+    apply_fn_until_same(&circ, |x: &CircuitRc| compiler_simp(x))
 }
 
 #[pyfunction]
 pub fn deep_push_down_index(circ: CircuitRc, min_size: Option<usize>) -> CircuitRc {
-    deep_map_unwrap_preorder(&circ, &|circ| {
+    deep_map_unwrap_preorder(&circ, |circ| {
         if min_size.is_none()
             || circ
                 .children()
@@ -299,7 +299,7 @@ pub fn deep_heuristic_nest_adds(circ: CircuitRc) -> CircuitRc {
         seen_adds.insert(new_sup.clone());
         mapping.insert(sup, new_sup.clone());
     }
-    deep_map_unwrap_preorder(&circ, &|c| {
+    deep_map_unwrap_preorder(&circ, |c| {
         c.map_or_clone(|add| {
             let add = mapping_until_end(add, &mapping);
 
@@ -356,7 +356,7 @@ pub fn deep_pull_concat_messy(circuit: CircuitRc, min_size: Option<usize>) -> Ci
 #[pyfunction]
 pub fn deep_pull_concat(circuit: CircuitRc, min_size: Option<usize>) -> CircuitRc {
     let pulled = deep_pull_concat_messy(circuit, min_size);
-    apply_fn_until_same(&pulled, &mut |x: &CircuitRc| {
+    apply_fn_until_same(&pulled, |x: &CircuitRc| {
         deep_push_down_index(compiler_simp(x), min_size)
     })
 }
