@@ -280,7 +280,6 @@ fn test_diags_intersection_union() {
 
 #[pyfunction]
 pub fn add_pull_diags(add: &Add) -> Option<Einsum> {
-    let _rank = add.info().rank();
     if !add
         .nodes
         .iter()
@@ -292,15 +291,15 @@ pub fn add_pull_diags(add: &Add) -> Option<Einsum> {
         .nodes_and_rank_differences()
         .iter()
         .map(|(node, rank_difference)| {
+            let rank_difference = *rank_difference as u8;
             let einsum = unwrap!(&***node, Circuit::Einsum);
-            (0..*rank_difference as u8)
+            (0..rank_difference)
                 .chain(zip(&einsum.info().shape, &einsum.out_axes).enumerate().map(
                     |(i, (l, x))| {
                         if *l > 1 {
-                            x + *rank_difference as u8
+                            x + rank_difference as u8
                         } else {
-                            (i + *rank_difference + *einsum.out_axes.iter().max().unwrap() as usize)
-                                as u8
+                            i as u8 + rank_difference + *einsum.out_axes.iter().max().unwrap() + 1
                         }
                     },
                 ))
