@@ -114,68 +114,65 @@ pub trait CircuitNode: CircuitNodePrivate {
 
     fn children<'a>(&'a self) -> Box<dyn Iterator<Item = CircuitRc> + 'a>;
 
-    fn map_children_enumerate<'a, F, E>(
-        &'a self,
-        f: &mut F,
-    ) -> Result<Self, CircuitConstructionError>
+    fn map_children_enumerate<'a, F, E>(&'a self, f: F) -> Result<Self, CircuitConstructionError>
     where
         Self: Sized,
         CircuitConstructionError: From<E>,
         F: FnMut(usize, &'a Circuit) -> Result<CircuitRc, E>;
 
-    fn map_children<'a, F, E>(&'a self, f: &mut F) -> Result<Self, CircuitConstructionError>
+    fn map_children<'a, F, E>(&'a self, mut f: F) -> Result<Self, CircuitConstructionError>
     where
         Self: Sized,
         CircuitConstructionError: From<E>,
         F: FnMut(&'a Circuit) -> Result<CircuitRc, E>,
     {
-        self.map_children_enumerate(&mut |_i, x| f(x))
+        self.map_children_enumerate(|_i, x| f(x))
     }
 
-    fn map_children_idxs<'a, F, E>(&'a self, f: &mut F) -> Result<Self, CircuitConstructionError>
+    fn map_children_idxs<'a, F, E>(&'a self, mut f: F) -> Result<Self, CircuitConstructionError>
     where
         Self: Sized,
         CircuitConstructionError: From<E>,
         F: FnMut(usize) -> Result<CircuitRc, E>,
     {
-        self.map_children_enumerate(&mut |i, _x| f(i))
+        self.map_children_enumerate(|i, _x| f(i))
     }
 
-    fn map_children_unwrap<'a, F>(&'a self, f: &mut F) -> Self
+    fn map_children_unwrap<'a, F>(&'a self, mut f: F) -> Self
     where
         Self: Sized,
         F: FnMut(&'a Circuit) -> CircuitRc,
     {
-        self.map_children(&mut |x| Ok::<CircuitRc, CircuitConstructionError>(f(x)))
+        self.map_children(|x| Ok::<CircuitRc, CircuitConstructionError>(f(x)))
             .unwrap()
     }
 
-    fn map_children_unwrap_enumerate<'a, F>(&'a self, f: &mut F) -> Self
+    fn map_children_unwrap_enumerate<'a, F>(&'a self, mut f: F) -> Self
     where
         Self: Sized,
         F: FnMut(usize, &'a Circuit) -> CircuitRc,
     {
-        self.map_children_enumerate(&mut |i, x| Ok::<CircuitRc, CircuitConstructionError>(f(i, x)))
+        self.map_children_enumerate(|i, x| Ok::<CircuitRc, CircuitConstructionError>(f(i, x)))
             .unwrap()
     }
 
-    fn map_children_unwrap_idxs<'a, F>(&'a self, f: &mut F) -> Self
+    fn map_children_unwrap_idxs<'a, F>(&'a self, mut f: F) -> Self
     where
         Self: Sized,
         F: FnMut(usize) -> CircuitRc,
     {
-        self.map_children_enumerate(&mut |i, _x| Ok::<CircuitRc, CircuitConstructionError>(f(i)))
+        self.map_children_enumerate(|i, _x| Ok::<CircuitRc, CircuitConstructionError>(f(i)))
             .unwrap()
     }
 
     /// if any return Some, return child mapped, otherwise None
-    fn map_children_op<'a, F>(&'a self, f: &mut F) -> Option<Self>
+    fn map_children_op<'a, F>(&'a self, mut f: F) -> Option<Self>
     where
         Self: Sized,
         F: FnMut(&'a Circuit) -> Option<CircuitRc>,
     {
         let mut any_modified = false;
-        let out = self.map_children_unwrap(&mut |x| {
+        let out = self.map_children_unwrap(|x| {
             if let Some(new) = f(x) {
                 any_modified = true;
                 new
@@ -269,7 +266,7 @@ pub trait CircuitNodeUnion {
     fn as_trait_obj_mut(&mut self) -> &mut dyn CircuitNode;
     fn map_children_enumerate_impl<'a, F, E>(
         &'a self,
-        f: &mut F,
+        f: F,
     ) -> Result<Self, CircuitConstructionError>
     where
         Self: Sized,
@@ -402,7 +399,7 @@ macro_rules! define_circuit_union_impl {
                 }
             }
 
-            fn map_children_enumerate_impl<'a, F, E>(&'a self, f: &mut F) -> Result<Self, $crate::circuit::CircuitConstructionError>
+            fn map_children_enumerate_impl<'a, F, E>(&'a self, f: F) -> Result<Self, $crate::circuit::CircuitConstructionError>
             where
                 $crate::circuit::CircuitConstructionError: From<E>,
                 F: FnMut(usize,&'a $crate::circuit::Circuit) -> Result<$crate::circuit::CircuitRc, E>,
@@ -630,10 +627,7 @@ impl<T: CircuitNodeUnion> CircuitNode for T {
         self.as_trait_obj().children()
     }
 
-    fn map_children_enumerate<'a, F, E>(
-        &'a self,
-        f: &mut F,
-    ) -> Result<Self, CircuitConstructionError>
+    fn map_children_enumerate<'a, F, E>(&'a self, f: F) -> Result<Self, CircuitConstructionError>
     where
         CircuitConstructionError: From<E>,
         F: FnMut(usize, &'a Circuit) -> Result<CircuitRc, E>,
@@ -873,7 +867,7 @@ pub fn evaluate_fn(circ: &Circuit) -> Result<Tensor, TensorEvalError> {
     recurse(circ.clone())
 }
 
-pub fn deep_map<F>(circuit: &Circuit, f: &F) -> Result<CircuitRc, CircuitConstructionError>
+pub fn deep_map<F>(circuit: &Circuit, f: F) -> Result<CircuitRc, CircuitConstructionError>
 where
     F: Fn(&Circuit) -> Result<CircuitRc, CircuitConstructionError>,
 {
@@ -887,7 +881,7 @@ where
     recurse(circuit)
 }
 
-pub fn deep_map_preorder<F>(circuit: &Circuit, f: &F) -> Result<CircuitRc, CircuitConstructionError>
+pub fn deep_map_preorder<F>(circuit: &Circuit, f: F) -> Result<CircuitRc, CircuitConstructionError>
 where
     F: Fn(&Circuit) -> Result<CircuitRc, CircuitConstructionError>,
 {
@@ -899,7 +893,7 @@ where
     recurse(circuit)
 }
 
-pub fn deep_map_unwrap<F>(circuit: &Circuit, f: &F) -> CircuitRc
+pub fn deep_map_unwrap<F>(circuit: &Circuit, f: F) -> CircuitRc
 where
     F: Fn(&Circuit) -> CircuitRc,
 {
@@ -914,7 +908,7 @@ where
 }
 
 /// this applies the function to parent before children, as opposed to deep_map_unwrap, which is children first
-pub fn deep_map_unwrap_preorder<F>(circuit: &Circuit, f: &F) -> CircuitRc
+pub fn deep_map_unwrap_preorder<F>(circuit: &Circuit, f: F) -> CircuitRc
 where
     F: Fn(&Circuit) -> CircuitRc,
 {
@@ -927,7 +921,7 @@ where
 }
 
 /// visits each subcircuit that's in any circuit once!
-pub fn visit_circuit<F>(circuit: &Circuit, f: &mut F)
+pub fn visit_circuit<F>(circuit: &Circuit, mut f: F)
 where
     F: FnMut(&Circuit),
 {
@@ -945,10 +939,10 @@ where
             }
         }
     }
-    recurse(circuit, &mut seen, f);
+    recurse(circuit, &mut seen, &mut f);
 }
 
-pub fn visit_circuit_fallable<F, E>(circuit: &Circuit, f: &mut F) -> Result<(), E>
+pub fn visit_circuit_fallable<F, E>(circuit: &Circuit, mut f: F) -> Result<(), E>
 where
     F: FnMut(&Circuit) -> Result<(), E>,
 {
@@ -967,10 +961,10 @@ where
         }
         Ok(())
     }
-    recurse(circuit, &mut seen, f)
+    recurse(circuit, &mut seen, &mut f)
 }
 
-pub fn visit_circuit_postorder<F>(circuit: &Circuit, f: &mut F)
+pub fn visit_circuit_postorder<F>(circuit: &Circuit, mut f: F)
 where
     F: FnMut(&Circuit),
 {
@@ -988,10 +982,10 @@ where
             f(circ);
         }
     }
-    recurse(circuit, &mut seen, f);
+    recurse(circuit, &mut seen, &mut f);
 }
 
-pub fn deep_map_op<F>(circuit: &Circuit, f: &F) -> Option<CircuitRc>
+pub fn deep_map_op<F>(circuit: &Circuit, f: F) -> Option<CircuitRc>
 where
     F: Fn(&Circuit) -> Option<CircuitRc>,
 {
@@ -999,7 +993,7 @@ where
         let mut recurse = |circ: &Circuit| -> Option<CircuitRc> = {
             let inner_mapped = circ.map_children_op(&mut recurse);
             inner_mapped
-                .map(|x| x.and_then_or_clone(f))
+                .map(|x| x.and_then_or_clone(&f))
                 .or_else(|| f(circ))
         };
     }
@@ -1103,7 +1097,7 @@ fn python_apply_fn_to_sub<N: CircuitNode>(
     node: &N,
     f: PyObject,
 ) -> Result<N, CircuitConstructionError> {
-    node.map_children(&mut |c| {
+    node.map_children(|c| {
         Python::with_gil(|py| -> Result<_, CircuitConstructionError> {
             let out = f.call1(py, (c.clone(),))?.extract::<CircuitRc>(py)?;
             Ok(out)
