@@ -63,7 +63,7 @@ impl From<Option<usize>> for OpSize {
 
 impl From<OpSize> for Option<usize> {
     fn from(x: OpSize) -> Self {
-        if x.0 << 63 == 1 {
+        if x.0 >> 63 == 1 {
             None
         } else {
             Some(x.0 as usize)
