@@ -411,7 +411,7 @@ impl TensorIndex {
                 .map(|(idx, &l)| match idx {
                     TensorAxisIndex::Single(i) => {
                         assert!(*i < l as i64 && *i >= -(l as i64));
-                        TensorAxisIndex::Single(*i)
+                        TensorAxisIndex::Single((*i + l as i64) % l as i64)
                     }
                     TensorAxisIndex::Tensor(t) => TensorAxisIndex::Tensor(t.clone()), // not bothering to canon tensor for now
                     TensorAxisIndex::Slice(sl) => TensorAxisIndex::Slice(sl.canonicalize(l)),
