@@ -220,7 +220,7 @@ pub fn mapping_until_end<T: Eq + Hash + Clone>(x: &T, mapping: &HashMap<T, T>) -
     result
 }
 
-pub fn apply_fn_until_same<T: Eq + Hash + Clone, F>(x: &T, f: &mut F) -> T
+pub fn apply_fn_until_same<T: Eq + Hash + Clone, F>(x: &T, f: F) -> T
 where
     F: Fn(&T) -> T,
 {
